@@ -21,7 +21,6 @@ import webbrowser
 from zebrazoom.code.vars import getGlobalVariables
 globalVariables = getGlobalVariables()
 
-from zebrazoom.mainZZ import mainZZ
 from zebrazoom.getTailExtremityFirstFrame import getTailExtremityFirstFrame
 import zebrazoom.code.popUpAlgoFollow as popUpAlgoFollow
 
@@ -120,16 +119,19 @@ class SeveralVideos(tk.Frame):
         tk.Label(self, text="", font=controller.title_font).pack()
         
         button4 = tk.Button(self, text="Manual first frame tail extremity for head embedded", bg="light yellow", command=lambda: controller.show_frame("TailExtremityHE")).pack()
-        tk.Label(self, text="This will allow you to manually select the tail extremities, you can run the tracking on multiple videos without interruptions afterwards.").pack()
+        tk.Label(self, text="This button allows you to only manually select the tail extremities,").pack()
+        tk.Label(self, text="you will be able to run the tracking on multiple videos without interruptions with the 'Run ZebraZoom on an entire folder' button above afterwards.").pack()
         tk.Label(self, text="", font=controller.title_font).pack()
         
         tk.Button(self, text="Only select the regions of interest", bg="light yellow", command=lambda: controller.show_frame("FolderMultipleROIInitialSelect")).pack()
         tk.Label(self, text="This is for the 'Multiple rectangular regions of interest chosen at runtime' option.").pack()
-        tk.Label(self, text="This will allow you to only select the ROIs, you can run the tracking on multiple videos without interruptions afterwards.").pack()
+        tk.Label(self, text="This button allows you to only select the ROIs,").pack()
+        tk.Label(self, text="you will be able to run the tracking on multiple videos without interruptions with the 'Run ZebraZoom on an entire folder' button above afterwards.").pack()
         tk.Label(self, text="", font=controller.title_font).pack()
         
         tk.Button(self, text="'Group of multiple same size and shape equally spaced wells' coordinates pre-selection", bg="light yellow", command=lambda: controller.show_frame("FolderMultipleROIInitialSelect")).pack()
-        tk.Label(self, text="This will allow you to only select the coordinates, you can run the tracking on multiple videos without interruptions afterwards.").pack()
+        tk.Label(self, text="This button allows you to only select the coordinates,").pack()
+        tk.Label(self, text="you will be able to run the tracking on multiple videos without interruptions with the 'Run ZebraZoom on an entire folder' button above afterwards.").pack()
         tk.Label(self, text="", font=controller.title_font).pack()
         
         tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()
@@ -191,7 +193,8 @@ class FolderToAnalyze(tk.Frame):
         tk.Label(self, text="Look for the folder you want to analyze.").pack(side="top", fill="x", pady=10)
         justExtractParams = IntVar()
         noValidationVideo = IntVar()
-        button = tk.Button(self, text="Choose folder", bg="light yellow", command=lambda: controller.chooseFolderToAnalyze(justExtractParams.get(), noValidationVideo.get()))
+        sbatchMode        = IntVar()
+        button = tk.Button(self, text="Choose folder", bg="light yellow", command=lambda: controller.chooseFolderToAnalyze(justExtractParams.get(), noValidationVideo.get(), sbatchMode.get()))
         button.pack()
         
         Checkbutton(self, text="I ran the tracking already, I only want to redo the extraction of parameters.", variable=justExtractParams).pack()
@@ -200,6 +203,9 @@ class FolderToAnalyze(tk.Frame):
         Checkbutton(self, text="Don't (re)generate a validation video (for speed efficiency).", variable=noValidationVideo).pack()
         tk.Label(self, text="", pady=0).pack()
         
+        Checkbutton(self, text="Expert use (don't click here unless you know what you're doing): Only generate a script to launch all videos in parallel with sbatch.", variable=sbatchMode).pack()
+        tk.Label(self, text="", pady=0).pack()
+        
         tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()
 
 
@@ -256,12 +262,25 @@ class ZZoutro(tk.Frame):
     def __init__(self, parent, controller):
         tk.Frame.__init__(self, parent)
         self.controller = controller
-        label = tk.Label(self, text="Analysis is finished.")
+        label = tk.Label(self, text="Finished.")
         label.pack(side="top", fill="x", pady=10)
         button = tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage"))
         button.pack()
 
 
+class ZZoutroSbatch(tk.Frame):
+
+    def __init__(self, parent, controller):
+        tk.Frame.__init__(self, parent)
+        self.controller = controller
+        tk.Label(self, text="Three files have been generated in the current folder:").pack(side="top", fill="x", pady=10)
+        tk.Label(self, text="launchZZ.sh, commands.txt, configFile.json").pack(side="top", fill="x", pady=10)
+        tk.Label(self, text="Place these three files on your server and type: 'sbatch launchZZ.sh' to launch the analysis on all videos in parallel").pack(side="top", fill="x", pady=10)
+        tk.Label(self, text="Before launching the parrallel tracking with sbatch, you may need to type: 'chmod +x launchZZ.sh'").pack(side="top", fill="x", pady=10)
+        tk.Label(self, text="You can follow the progress with the commands 'squeueme' and by looking into the slurm* file being generated with 'cat slurm*'").pack(side="top", fill="x", pady=10)
+        button = tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage"))
+        button.pack()
+
 class ResultsVisualization(tk.Frame):
 
     def __init__(self, parent, controller):
@@ -274,10 +293,7 @@ class ResultsVisualization(tk.Frame):
         label = tk.Label(self, text="Choose the results you'd like to visualize", font=controller.title_font)
         label.grid(row=0,column=0)
         
-        cur_dir_path = os.path.dirname(os.path.realpath(__file__))
-        path = Path(cur_dir_path)
-        path = path.parent.parent
-        reference = os.path.join(path, 'ZZoutput')
+        reference = controller.ZZoutputLocation
         
         if not(os.path.exists(reference)):
           os.mkdir(reference)
@@ -349,19 +365,15 @@ class ViewParameters(tk.Frame):
         
         if name != "abc":
           
-          cur_dir_path = os.path.dirname(os.path.realpath(__file__))
-          path = Path(cur_dir_path)
-          path = path.parent.parent
-          reference = os.path.join(path, os.path.join('ZZoutput', os.path.join(name, 'results_' + name + '.txt')))
-          
+          reference = os.path.join(controller.ZZoutputLocation, os.path.join(name, 'results_' + name + '.txt'))
           if not(os.path.exists(reference)):
-            mypath = os.path.join(path, os.path.join('ZZoutput', name))
+            mypath = os.path.join(controller.ZZoutputLocation, name)
             onlyfiles = [f for f in os.listdir(mypath) if os.path.isfile(os.path.join(mypath, f))]
             resultFile = ''
             for fileName in onlyfiles:
               if 'results_' in fileName:
                 resultFile = fileName
-            reference = os.path.join(path, os.path.join('ZZoutput', os.path.join(name, resultFile)))
+            reference = os.path.join(controller.ZZoutputLocation, os.path.join(name, resultFile))
           
           if controller.justEnteredViewParameter == 1:
             with open(reference) as ff:
